@@ -1,7 +1,7 @@
 use crate::cli::Opt;
 use dirs::config_dir;
 use std::io::Read;
-use std::path::Path;
+use std::path::{Path, PathBuf};
 
 pub const PKG_NAME: &str = env!("CARGO_PKG_NAME");
 
@@ -33,6 +33,17 @@ impl Opt {
             path.push(format!("{}.toml", PKG_NAME));
             if Path::exists(&path) {
                 return Opt::from_config_file(&path);
+            } else if cfg!(target_os = "macos") {
+                if let Ok(home) = std::env::var("HOME") {
+                    let path = PathBuf::from(home)
+                        .join(".config")
+                        .join(PKG_NAME)
+                        .join(format!("{}.toml", PKG_NAME));
+
+                    if Path::exists(&path) {
+                        return Opt::from_config_file(&path);
+                    }
+                }
             }
         }
         Ok(Opt::default())
